@@ -10,7 +10,6 @@ package exporter
 
 import (
 	"fmt"
-	"math/rand"
 	"net/http/httptest"
 	"os"
 	"strings"
@@ -245,6 +244,65 @@ func TestIncludeConfigMetrics(t *testing.T) {
 	}
 }
 
+func TestClientOutputBufferLimitMetrics(t *testing.T) {
+	for _, class := range []string{
+		`normal`,
+		`pubsub`,
+		`slave`,
+	} {
+		for _, limit := range []string{
+			`hard`,
+			`soft`,
+		} {
+			want := fmt.Sprintf("%s{class=\"%s\",limit=\"%s\"}", "config_client_output_buffer_limit_bytes", class, limit)
+			r := prometheus.NewRegistry()
+			ts := httptest.NewServer(promhttp.HandlerFor(r, promhttp.HandlerOpts{}))
+			e, _ := NewRedisExporter(os.Getenv("TEST_REDIS_URI"), Options{Namespace: "test"})
+			r.Register(e)
+
+			body := downloadURL(t, ts.URL+"/metrics")
+
+			if !strings.Contains(body, want) {
+				t.Errorf("want metrics to include %s, have:\n%s", want, body)
+			}
+		}
+
+		want := fmt.Sprintf("%s{class=\"%s\",limit=\"soft\"}", "config_client_output_buffer_limit_overcome_seconds", class)
+		r := prometheus.NewRegistry()
+		ts := httptest.NewServer(promhttp.HandlerFor(r, promhttp.HandlerOpts{}))
+		e, _ := NewRedisExporter(os.Getenv("TEST_REDIS_URI"), Options{Namespace: "test"})
+		r.Register(e)
+
+		body := downloadURL(t, ts.URL+"/metrics")
+
+		if !strings.Contains(body, want) {
+			t.Errorf("want metrics to include %s, have:\n%s", want, body)
+		}
+	}
+}
+
+func TestExcludeConfigMetricsViaCONFIGCommand(t *testing.T) {
+	for _, inc := range []bool{false, true} {
+		r := prometheus.NewRegistry()
+		ts := httptest.NewServer(promhttp.HandlerFor(r, promhttp.HandlerOpts{}))
+		e, _ := NewRedisExporter(os.Getenv("TEST_REDIS_URI"),
+			Options{
+				Namespace:         "test",
+				ConfigCommandName: "-",
+				InclConfigMetrics: inc})
+		r.Register(e)
+
+		what := `test_config_key_value{key="appendonly",value="no"}`
+
+		body := downloadURL(t, ts.URL+"/metrics")
+		if strings.Contains(body, what) {
+			t.Fatalf("found test_config_key_value but should have skipped CONFIG call")
+		}
+
+		ts.Close()
+	}
+}
+
 func TestNonExistingHost(t *testing.T) {
 	e, _ := NewRedisExporter("unix:///tmp/doesnt.exist", Options{Namespace: "test"})
 
@@ -380,8 +438,6 @@ func TestKeyDbMetrics(t *testing.T) {
 }
 
 func init() {
-	rand.Seed(time.Now().UnixNano())
-
 	ll := strings.ToLower(os.Getenv("LOG_LEVEL"))
 	if pl, err := log.ParseLevel(ll); err == nil {
 		log.Printf("Setting log level to: %s", ll)
